using System;
using System.Collections;
using System.Diagnostics;
using System.Drawing;
using System.Runtime.Serialization;
using System.Windows.Forms;
using System.IO;
using System.Drawing.Imaging;
using System.ComponentModel;

using Syncfusion.Diagnostics;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Styles;

namespace FloatNumericButton
{
	
	//# region CustomProperties_with expandable objects

	public class FloatNumericUpDownStyleProperties : GridStyleInfoCustomProperties
	{
		// static initialization of property descriptors
		static Type t = typeof(FloatNumericUpDownStyleProperties);

        readonly static StyleInfoProperty NumericUpDownInfoProperty = CreateStyleInfoProperty(t, "FloatNumericUpDownProperties");
		
		// default settings for all properties this object holds
		static FloatNumericUpDownStyleProperties defaultObject;

		// initialize default settings for all properties in static ctor
		static FloatNumericUpDownStyleProperties ()
		{
			// all properties must be initialized for the Default property
			defaultObject = new FloatNumericUpDownStyleProperties(GridStyleInfo.Default);
			defaultObject.FloatNumericUpDownProperties=FloatNumericUpDownProperties.Default;
			
		}
			
		/// <summary>
		/// Provides access to default values for this type
		/// </summary>
		public static FloatNumericUpDownStyleProperties Default
		{
			get
			{
				return defaultObject;
			}
		}

		/// <summary>
		/// Force static ctor being called at least once
		/// </summary>
		public static void Initialize()
		{
		}

		public static explicit operator FloatNumericUpDownStyleProperties(GridStyleInfo style)
		{
			return new FloatNumericUpDownStyleProperties(style);
		}
		
		public FloatNumericUpDownStyleProperties(GridStyleInfo style)
			: base(style)
		{

		}
	
		public FloatNumericUpDownStyleProperties()
			: base()
		{
		}
        [
        Description("Numeric Up Down properties"),
        Browsable(true),
        Category("Custom")
        ]
        
        public FloatNumericUpDownProperties FloatNumericUpDownProperties
		{
			get
			{
                return FloatNumericUpDownProperties.Default;
			}
			set
			{
                style.SetValue(NumericUpDownInfoProperty, value);
			}
		}

	}

	[
	Serializable,
	StaticDataField("sd")
	]
	public class NumericUpDownStyleStore: StyleInfoStore
	{
		static StaticData sd = new StaticData(typeof(NumericUpDownStyleStore), typeof(FloatNumericUpDownProperties), true);
			
		public readonly static StyleInfoProperty NumericMinimumProperty = sd.CreateStyleInfoProperty(typeof(double), "NumericMinimum"); 
		
		public readonly static StyleInfoProperty NumericMaximumProperty = sd.CreateStyleInfoProperty(typeof(double), "NumericMaximum"); 
		
		public readonly static StyleInfoProperty NumericStepProperty = sd.CreateStyleInfoProperty(typeof(double), "NumericStep"); 
		
		public readonly static StyleInfoProperty NumericStartValueProperty = sd.CreateStyleInfoProperty(typeof(double), "NumericStartValue"); 
		
		public readonly static StyleInfoProperty NumericWrapValueProperty = sd.CreateStyleInfoProperty(typeof(double), "NumericWrapValue"); 

		public readonly static StyleInfoProperty NumericDecimalPlacesProperty = sd.CreateStyleInfoProperty(typeof(int), "NumericDecimalPlaces");
	
		public readonly static StyleInfoProperty NumericOrientationProperty = sd.CreateStyleInfoProperty(typeof(int), "NumericOrientation");

		public readonly static StyleInfoProperty NumericThousandsSeparatorProperty = sd.CreateStyleInfoProperty(typeof(bool), "NumericThousandsSeparator"); 
		
		public readonly static StyleInfoProperty NumericInterceptArrowkeysProperty = sd.CreateStyleInfoProperty(typeof(bool), "NumericInterceptArrowkeys"); 
		protected override StaticData StaticDataStore
		{
			get { return sd; }
		}

		public NumericUpDownStyleStore()
		{
		}

		private NumericUpDownStyleStore(SerializationInfo info, StreamingContext context)
			: base(info, context)
		{
		}
			
		public override object Clone()
		{
			StyleInfoStore target =new NumericUpDownStyleStore();
			CopyTo(target);
			return target;
		}
	}

	[TypeConverter(typeof(StyleInfoBaseConverter))]
	public class FloatNumericUpDownProperties:GridStyleInfoSubObject
	{
		// Static Fields
		private static FloatNumericUpDownProperties defaultNumericUpDownProperties;

		internal static object CreateObject(StyleInfoSubObjectIdentity identity, object store)
		{
			if (store != null)
				return new FloatNumericUpDownProperties(identity, store as NumericUpDownStyleStore);
			return new FloatNumericUpDownProperties(identity);
		}		
//		
		public override void Dispose()
		{
			base.Dispose();
		}		
		[DebuggerStepThrough()] public FloatNumericUpDownProperties()
			: base(new NumericUpDownStyleStore())
		{
		}
	
		[DebuggerStepThrough()] public FloatNumericUpDownProperties(StyleInfoSubObjectIdentity identity)
			: base(identity, new NumericUpDownStyleStore())
		{
			
		}
		[DebuggerStepThrough()] public FloatNumericUpDownProperties(StyleInfoSubObjectIdentity identity, NumericUpDownStyleStore store)
			: base(identity, store)
		{
		}

		[DebuggerStepThrough()] 
		public FloatNumericUpDownProperties(Font font)
			: base(new NumericUpDownStyleStore())
		{
				
		}

		[DebuggerStepThrough()] public override IStyleInfoSubObject MakeCopy(StyleInfoBase newOwner, StyleInfoProperty sip)
		{
			return new FloatNumericUpDownProperties(newOwner.CreateSubObjectIdentity(sip), (NumericUpDownStyleStore) Store.Clone());
		}

		public static FloatNumericUpDownProperties Default
		{
			[DebuggerStepThrough()] 
			get
			{
				if (defaultNumericUpDownProperties== null)
				{
					
					defaultNumericUpDownProperties= new FloatNumericUpDownProperties();
					defaultNumericUpDownProperties.Maximum=double.MaxValue;
					defaultNumericUpDownProperties.Minimum=double.MinValue;
					defaultNumericUpDownProperties.StartValue=0;
					defaultNumericUpDownProperties.Step=1;
					defaultNumericUpDownProperties.WrapValue=false;
					//New
					defaultNumericUpDownProperties.DecimalPlaces= 0;					
					defaultNumericUpDownProperties.Orientation=OrientationType.Vertical;
					defaultNumericUpDownProperties.ThousandsSeparator = false;
					defaultNumericUpDownProperties.InterceptArrowkeys = false;
					
					
				}
				return defaultNumericUpDownProperties;
			}
		}

		/// <override/>
		protected override void OnStyleChanged(StyleInfoProperty sip)
		{
			base.OnStyleChanged(sip);
		}
			
		/// <override/>
		protected override StyleInfoBase GetDefaultStyle()
		{
			return Default;
		}
		// Properties
		#region WrapValue
		/// <summary>
		/// True if value should be starting over when value reaches maximum or minimum.
		/// </summary>
		[
		Browsable(true),
		Description("true if value should be starting over when value reaches maximum or minimum."),
		
		]
		public bool WrapValue
		{
			get 
			{
				return (bool) GetValue(NumericUpDownStyleStore.NumericWrapValueProperty);
			}
			set 
			{
				SetValue(NumericUpDownStyleStore.NumericWrapValueProperty, (object) value);
			}
		}
		/// <summary>
		/// Resets the <see cref="WrapValue"/> property.
		/// </summary>
		public void ResetWrapValue()
		{
			ResetValue(NumericUpDownStyleStore.NumericWrapValueProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeWrapValue()
		{
			return HasValue(NumericUpDownStyleStore.NumericWrapValueProperty);
		}
		/// <summary>
		/// Checks if <see cref="WrapValue"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasWrapValue
		{
			get
			{
				return HasValue(NumericUpDownStyleStore.NumericWrapValueProperty);
			}
		}
		#endregion
		#region Minimum
		/// <summary>
		/// Minimum value.
		/// </summary>
		[
		Browsable(true),
		Description("Minimum value"),
		
		]
		public double Minimum
		{
			get 
			{
				return (double) GetValue(NumericUpDownStyleStore.NumericMinimumProperty);
			}
			set 
			{
				SetValue(NumericUpDownStyleStore.NumericMinimumProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="Minimum"/> property.
		/// </summary>
		public void ResetMinimum()
		{
			ResetValue(NumericUpDownStyleStore.NumericMaximumProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeMinimum()
		{
			return HasValue(NumericUpDownStyleStore.NumericMinimumProperty);
		}
		/// <summary>
		/// Checks if <see cref="Minimum"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasMinimum
		{
			get
			{
				return HasValue(NumericUpDownStyleStore.NumericMinimumProperty);
			}
		}
		#endregion
		#region Maximum
		/// <summary>
		/// Maximum value.
		/// </summary>
		[
		//Browsable(true),
		Description("Maximum value."),
		
		]
		public double Maximum
		{
			get 
			{
				return (double) GetValue(NumericUpDownStyleStore.NumericMaximumProperty);
			}
			set 
			{
				SetValue(NumericUpDownStyleStore.NumericMaximumProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="Maximum"/> property.
		/// </summary>
		public void ResetMaximum()
		{
			ResetValue(NumericUpDownStyleStore.NumericMaximumProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeMaximum()
		{
			return HasValue(NumericUpDownStyleStore.NumericMaximumProperty);
		}
		/// <summary>
		/// Checks if <see cref="Maximum"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasMaximum
		{
			get
			{
				return HasValue(NumericUpDownStyleStore.NumericMaximumProperty);
			}
		}
		#endregion
		#region Step
		/// <summary>
		/// The step to increase or decrease when clicking up or down buttons.
		/// </summary>
		[
		Browsable(true),
		Description("The step to increase or decrease when clicking up or down buttons."),
		
		]
		public double Step
		{
			get 
			{
				return (double) GetValue(NumericUpDownStyleStore.NumericStepProperty);
			}
			set 
			{
				SetValue(NumericUpDownStyleStore.NumericStepProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="Step"/> property.
		/// </summary>
		public void ResetStep()
		{
			ResetValue(NumericUpDownStyleStore.NumericStepProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeStep()
		{
			return HasValue(NumericUpDownStyleStore.NumericStepProperty);
		}
		/// <summary>
		/// Checks if <see cref="Step"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasStep
		{
			get
			{
				return HasValue(NumericUpDownStyleStore.NumericStepProperty);
			}
		}
		#endregion
		#region StartValue
		/// <summary>
		/// Start value. This is the first value when you press up or down in an empty cell.
		/// </summary>
		[
		Browsable(true),
		Description("Start value. This is the first value when you press up or down in an empty cell."),
		
		]
		public double StartValue
		{
			get 
			{
				return (double) GetValue(NumericUpDownStyleStore.NumericStartValueProperty);
			}
			set 
			{
				SetValue(NumericUpDownStyleStore.NumericStartValueProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="StartValue"/> property.
		/// </summary>
		public void ResetStartValue()
		{
			ResetValue(NumericUpDownStyleStore.NumericStartValueProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeStartValue()
		{
			return HasValue(NumericUpDownStyleStore.NumericStartValueProperty);
		}
		/// <summary>
		/// Checks if <see cref="StartValue"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasStartValue
		{
			get
			{
				return HasValue(NumericUpDownStyleStore.NumericStartValueProperty);
			}
		}
		#endregion
		public enum OrientationType
		{
			Vertical=0,
			Horizontal=1,
		}

		//Properties
		#region Orientation
		
		public OrientationType Orientation
		{
			get
			{
				return (OrientationType)GetValue(NumericUpDownStyleStore.NumericOrientationProperty);
			}
			set
			{
				SetValue(NumericUpDownStyleStore.NumericOrientationProperty, value);				
			}
		}
		#endregion
		#region  DecimalPlaces 
		
		public int DecimalPlaces 
		{
			get 
			{
				return (int) GetValue(NumericUpDownStyleStore.NumericDecimalPlacesProperty);
			}
			set 
			{
				SetValue(NumericUpDownStyleStore.NumericDecimalPlacesProperty, value);
			}
		}
		#endregion
		#region Thousands Separator
		/// <summary>
		///This property specifies the width of the button
		/// </summary>
		[Description("Specifies the width of the button"),
		Browsable(true),
		Category("Custom"),
		NotifyParentProperty(true)
		]
		public bool ThousandsSeparator
		{
			get
			{
				return (bool)GetValue(NumericUpDownStyleStore.NumericThousandsSeparatorProperty);
			}
			set
			{
				SetValue(NumericUpDownStyleStore.NumericThousandsSeparatorProperty, value);
			}
		}
		#endregion
		#region Intercept Arrowkeys
		
		[Description("Up and down keys Performs the same function as up and down arrow keys"),
		Browsable(true),
		Category("Custom"),
		NotifyParentProperty(true)
		]
		public bool InterceptArrowkeys
		{
			get
			{
				return (bool)GetValue(NumericUpDownStyleStore.NumericInterceptArrowkeysProperty);
			}
			set
			{
				SetValue(NumericUpDownStyleStore.NumericInterceptArrowkeysProperty, value);
			}
		}
		#endregion
	
		
	}
}
